import {
  api,
  downloadFile,
  createApiUrl
} from '~/utils/axios';


/**
 * 导出教学环境类型
 * @param {Object} data
 * @return {Promise} api
 */
export function exportExcel(data) {
  downloadFile(createApiUrl('AboutUs.TeachingEnvir.TeachingEnvirType/exportExcel'), data);
}

/**
 * 下载教学环境类型模板
 * @param {Object} data
 * @return {Promise} api
 */
export function downloadTemplate(data) {
  downloadFile(createApiUrl('AboutUs.TeachingEnvir.TeachingEnvirType/downloadTemplate'), data);
}

/**
 * 导入教学环境类型
 * @param {Object} data
 * @return {Promise} api
 */
export const importExcel = createApiUrl('AboutUs.TeachingEnvir.TeachingEnvirType/importExcel');

/**
 * 获取教学环境类型列表
 * @param {Object} data
 * @return {Promise} api
 */
export function getTeachingEnvirTypeList(data) {
  return api.post('AboutUs.TeachingEnvir.TeachingEnvirType/getTeachingEnvirTypeList', data);
}

/**
 * 删除教学环境类型
 * @param {Object} data
 * @return {Promise} api
 */
export function deleteTeachingEnvirType(data) {
  return api.post('AboutUs.TeachingEnvir.TeachingEnvirType/deleteTeachingEnvirType', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '删除失败'
  });
}

/**
 * 添加教学环境类型
 * @param {Object} data
 * @return {Promise} api
 */
export function addTeachingEnvirType(data) {
  return api.post('AboutUs.TeachingEnvir.TeachingEnvirType/addTeachingEnvirType', data, {
    // isTransformResponse: true,
    // isShowSuccessMessage: true,
    errorMessageText: '添加失败'
  });
}
/**
 * 编辑教学环境类型
 * @param {Object} data
 * @return {Promise} api
 */
export function editTeachingEnvirType(data) {
  return api.post('AboutUs.TeachingEnvir.TeachingEnvirType/editTeachingEnvirType', data, {
    // isTransformResponse: true,
    // isShowSuccessMessage: true,
    errorMessageText: '编辑失败'
  });
}